@@ -51,4 +51,11 @@ def generatePass(length: int) -> int:
     for x in range(length):
         charter = random.choice(krack)
         word += charter
-    return word
\ No newline at end of file
+    return word
+def tempConv(from_temp: str, to_temp: str, temp: float) -> float:
+    if from_temp == "c" and to_temp == "f":
+        return temp * 9/5 + 32
+    elif from_temp == "f" and to_temp == "c":
+        return (temp - 32) * 5/9
+    else:
+        raise SimeLibraryError("These settings are not supported by the library.")
\ No newline at end of file
